==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/igc-child-content-component.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { TypeRegistrar } from './type';
import { IgcHTMLElement } from './igc-html-element';
var IgcChildContentComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(IgcChildContentComponent, _super);
    function IgcChildContentComponent() {
        var _this = _super.call(this) || this;
        _this._display = "inline-block";
        _this._flexDirection = "row";
        _this._alignItems = "center";
        _this._attached = false;
        return _this;
    }
    Object.defineProperty(IgcChildContentComponent.prototype, "display", {
        get: function () {
            return this._display;
        },
        set: function (value) {
            this._display = value;
            this.style.display = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgcChildContentComponent.prototype, "flexDirection", {
        get: function () {
            return this._flexDirection;
        },
        set: function (value) {
            this._flexDirection = value;
            this.style.flexDirection = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgcChildContentComponent.prototype, "alignItems", {
        get: function () {
            return this._alignItems;
        },
        set: function (value) {
            this._alignItems = value;
            this.style.alignItems = value;
        },
        enumerable: true,
        configurable: true
    });
    IgcChildContentComponent.prototype.onChildrenChanged = function (children) {
        for (var i = 0; i < children.length; i++) {
            var child = children[i];
            child.remove();
            this.appendChild(child);
        }
    };
    IgcChildContentComponent.prototype.connectedCallback = function () {
        this.attachedCallback();
    };
    IgcChildContentComponent.prototype.attachedCallback = function () {
        this._attached = true;
    };
    IgcChildContentComponent.register = function () {
        if (!IgcChildContentComponent._registered) {
            IgcChildContentComponent._registered = true;
            if (window.customElements) {
                window.customElements.define(IgcChildContentComponent.htmlTagName, IgcChildContentComponent);
            }
            else {
                document.registerElement(IgcChildContentComponent.htmlTagName, IgcChildContentComponent);
            }
            TypeRegistrar.registerCons("IgcChildContentComponent", IgcChildContentComponent);
        }
    };
    IgcChildContentComponent.htmlTagName = "igc-child-content";
    IgcChildContentComponent._registered = false;
    return IgcChildContentComponent;
}(IgcHTMLElement));
export { IgcChildContentComponent };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/igc-child-content-component.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { TypeRegistrar } from './type';
import { IgcHTMLElement } from './igc-html-element';
var IgcChildContentComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcChildContentComponent, _super);
    function IgcChildContentComponent() {
        var _this = _super.call(this) || this;
        _this._display = "inline-block";
        _this._flexDirection = "row";
        _this._alignItems = "center";
        _this._attached = false;
        return _this;
    }
    Object.defineProperty(IgcChildContentComponent.prototype, "display", {
        get: function () {
            return this._display;
        },
        set: function (value) {
            this._display = value;
            this.style.display = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcChildContentComponent.prototype, "flexDirection", {
        get: function () {
            return this._flexDirection;
        },
        set: function (value) {
            this._flexDirection = value;
            this.style.flexDirection = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcChildContentComponent.prototype, "alignItems", {
        get: function () {
            return this._alignItems;
        },
        set: function (value) {
            this._alignItems = value;
            this.style.alignItems = value;
        },
        enumerable: false,
        configurable: true
    });
    IgcChildContentComponent.prototype.onChildrenChanged = function (children) {
        for (var i = 0; i < children.length; i++) {
            var child = children[i];
            child.remove();
            this.appendChild(child);
        }
    };
    IgcChildContentComponent.prototype.connectedCallback = function () {
        this.attachedCallback();
    };
    IgcChildContentComponent.prototype.attachedCallback = function () {
        this._attached = true;
    };
    IgcChildContentComponent.register = function () {
        if (!IgcChildContentComponent._registered) {
            IgcChildContentComponent._registered = true;
            if (window.customElements) {
                window.customElements.define(IgcChildContentComponent.htmlTagName, IgcChildContentComponent);
            }
            else {
                document.registerElement(IgcChildContentComponent.htmlTagName, IgcChildContentComponent);
            }
            TypeRegistrar.registerCons("IgcChildContentComponent", IgcChildContentComponent);
        }
    };
    IgcChildContentComponent.htmlTagName = "igc-child-content";
    IgcChildContentComponent._registered = false;
    return IgcChildContentComponent;
}(IgcHTMLElement));
export { IgcChildContentComponent };
